==> guile-2.0.7.tar.xz: lib/guile/2.0/ccache/texinfo/docbook.go <==
GOOF----LE-4-2.0#&      ]  4  h      ] g  guile	 	g  define-module*	 	 	g  texinfo	g  docbook	 		g  filenameS	
f  texinfo/docbook.scm	g  importsS	g  sxml	
g  fold	
 	 	g  srfi	g  srfi-1	 	g  selectS	
 	 	 	g  exportsS	g  *sdocbook->stexi-rules*	g  *sdocbook-block-commands*	g  sdocbook-flatten	g  filter-empty-elements	g  replace-titles	 	g  set-current-module	 	  	!g  identity	"g  @	#g  identity-deattr	$g  	detag-one	%g  	parameter	&g  var	'%& 	(g  replaceable	)(& 	*g  type	+g  code	,*+ 	-g  function	.-+ 	/g  literal	0g  samp	1/0 	2g  emphasis	3g  emph	423 	5g  simpara	6g  para	756 	8g  programlisting	9g  example	:89 	;g  	firstterm	<g  dfn	=;< 	>g  filename	?g  file	@>? 	Ag  quote	Bg  cite	CAB 	Dg  application	EDB 	Fg  symbol	GF+ 	Hg  note	Ig  	cartouche	JHI 	Kg  envar	Lg  env	MKL 	N'),.147:=@CEGJM 	Og  tag-replacements	Pg  ignore-list	Qg  with-output-to-string	Rg  write	Sg  	stringify	Tg  
*preorder*	Ug  %	Vg  orderedlist	Wg  listitem	Xg  item	Yg  	enumerate	Zg  itemizedlist	[g  itemize	\g  acronym	]g  term	^g  informalexample	_g  section	`g  
subsection	ag  
subsubsection	bg  ulink	cg  assq	dg  url	eg  uref	fg  title	gg  *text*	hg  	*default*	ig  append	jg  warn	kf  Ignoring	lf  
attributes	mg  memq	nf  Don't know how to convert	of  to stexi	pg  c	qg  all	rg  	indexterm	sg  variablelist	tg  refsect1	ug  refsect2	vg  refsect3	wg  refsect4	x68^rsVtuvwf9HZ 	yg  inline-command?	zi 	{i 	|g  reverse	}g  foldts*-values	~g  chapter	t~ u_ v` wa  C 5h     ]4	
5 4  >  "  G     h   o   -  1  3  C    g       g  args
			  g  filenamef  texinfo/docbook.scm
	(
 			


  g  nameg  identity C!R"        h@      - 1 3  $  %$  &  "  "  "  C            g  tag
			; g  body			;  g  filenamef  texinfo/docbook.scm
	+
		,			,			,	(		,	!		,			-		 	-	%	$	,		'	.		:	,	 			;
  g  nameg  identity-deattr C#R     h      ]C   w       g  tag
		 g  body		  g  filenamef  texinfo/docbook.scm
	1
 			  g  nameg  	detag-one C$RNORPRQR    h   N   ] L 6F       g  filenamef  texinfo/docbook.scm
	H			H	$ 		
   C       h   u   ] O 6   m       g  exp
		
  g  filenamef  texinfo/docbook.scm
	G
	
	H	 		
  g  nameg  	stringify CSR"T!iUT!i6#iVWX   h   s   - 1 3 C k       g  tag
			 g  body			  g  filenamef  texinfo/docbook.scm
	R			S	 			
   C Y   h   s   - 1 3 C k       g  tag
			 g  body			  g  filenamef  texinfo/docbook.scm
	T			U	 			
   CZWX h   s   - 1 3 C k       g  tag
			 g  body			  g  filenamef  texinfo/docbook.scm
	W			X	 			
   C [   h   s   - 1 3 C k       g  tag
			 g  body			  g  filenamef  texinfo/docbook.scm
	Y			Z	 			
   C\\U h    s   - 1 3   C       k       g  tag
			 g  body			  g  filenamef  texinfo/docbook.scm
	[			\	 			
   C]$i^$i_!i`!ia!ibcdeUf h8      - 1 3 45$    CC              g  tag
			1 g  attrs			1 g  body				1 g  t			1  g  filenamef  texinfo/docbook.scm
	b		
	d			d			d			d			c			f		0	h	 				1	
	   Cg$ihcOi"jklmPnopUqS     h     - 1 3 4 5$  U"  	6$  =$  1&  #4 >  "  G  6"""4 	5$  C4
 >  "  G  
4 5   C        g  tag
		  g  body		  g  subst		   g  filenamef  texinfo/docbook.scm
	j		
	k	!		k			l		#	r	$	'	r		'	n		*	n	!	.	n		1	n	5	2	n	.	6	n		9	n	F	<	n	R	@	n		A	p		E	p	$	I	p	3	L	p	@	Q	p		^	q	&	a	q	2	c	q		p	s		|	l			u	 	u	 	u	> 	u	 	v	 	v	% 	v	0 	v	% 	v	 #		 
   C RxRm  h      ]4 5C          g  command
		
  g  filenamef  texinfo/docbook.scm
 
	 		 	 		
  g  nameg  inline-command? CyRU{|       h(      ]L4L $  	L  "  4 55D          g  accum
		% g  block		%  g  filenamef  texinfo/docbook.scm
 		 		
 		 	(	 	5	 		  		% 	 			%	   C        hX   n  ]  $  & $   &   "  "  "  $   "   O D  f      g  node
		V g  accum		V g  block			V g  cont			V g  command		4	V g  attrs		4	V  g  filenamef  texinfo/docbook.scm
 		 		 			 		
 		 	0	 	)	 		 		 	(	! 		$ 		4 		> 		A 		I 	$	J 		K 		V 	 		V	  g  nameg  fdown C}yi        hH   y  ]4>  G 45$  45D45D  q      g  node
		F g  paccum		F g  pblock			F g  pcont			F g  kaccum			F g  kblock			F g  kcont			F g  ret			F g  block			F  	g  filenamef  texinfo/docbook.scm
 		 	!	 		 		 		 		" 		' 		( 	&	4 		7 		@ 	*	B 		F 	 		F	  g  nameg  fup C     h      ] D          g  str
		
 g  accum		
 g  block			
 g  cont			
  g  filenamef  texinfo/docbook.scm
 		 		
 	 		
	  g  nameg  fhere C|      h0   "  ]!4 >  G 6             g  sdocbook
		) g  fdown		) g  accum			) g  block			) g  cont			)  g  filenamef  texinfo/docbook.scm
 
	 		 	:	 	>	 		 		) 	 		)  g  nameg  sdocbook-flatteng  
documentationf "Flatten" a fragment of sdocbook so that block elements do not nest
inside each other.

Docbook is a nested format, where e.g. a @code{refsect2} normally
appears inside a @code{refsect1}. Logical divisions in the document are
represented via the tree topology; a @code{refsect2} element
@emph{contains} all of the elements in its section.

On the contrary, texinfo is a flat format, in which sections are marked
off by standalone section headers like @code{@@chapter}, and block
elements do not nest inside each other.

This function takes a nested sdocbook fragment @var{sdocbook} and
flattens all of the sections, such that e.g.
@example
 (refsect1 (refsect2 (para "Hello")))
@end example
becomes
@example
 ((refsect1) (refsect2) (para "Hello"))
@end example

Oftentimes (always?) sectioning elements have @code{<title>} as their
first element child; users interested in processing the @code{refsect*}
elements into proper sectioning elements like @code{chapter} might be
interested in @code{replace-titles} and @code{filter-empty-elements}.
@xref{texinfo docbook replace-titles,,replace-titles}, and @ref{texinfo
docbook filter-empty-elements,,filter-empty-elements}.

Returns a nodeset, as described in @ref{sxml xpath}. That is to say,
this function returns an untagged list of stexi elements. CR|
    h(      ]"   C $   (  C""          g  x
		% g  rest		%  g  filenamef  texinfo/docbook.scm
 		 	
	 		 		 		 	 	 	
 		%	   C      h      ]4 56      g  sdocbook
		  g  filenamef  texinfo/docbook.scm
 
	 		
 		 		 	 		  g  nameg  filter-empty-elementsg  
documentationf  gFilters out empty elements in an sdocbook nodeset. Mostly useful
after running @code{sdocbook-flatten}. CR|c   hh     ]"  U(  6$  45"  $  "" "        g  sdocbook-fragment
		f g  in		[ g  out			[ g  t		*	[  g  filenamef  texinfo/docbook.scm
 
	 		 		 		 		 		 		 		  	"	# 		% 		* 		5 		9 	"	< 	/	? 		B 		J 		M 	
	P 		S 		[ 		[ 		^ 	'	f 	 		f  g  nameg  replace-titlesg  
documentationf rIterate over the sdocbook nodeset @var{sdocbook-fragment},
transforming contiguous @code{refsect} and @code{title} elements into
the appropriate texinfo sectioning command. Most useful after having run
@code{sdocbook-flatten}.

For example:
@example
 (replace-titles '((refsect1) (title "Foo") (para "Bar.")))
    @result{} '((chapter "Foo") (para "Bar."))
@end example
 CRC          g  m
		,  g  filenamef  texinfo/docbook.scm		
 	(
	+
	1
	5		4
	E		E
	G
	N	
q	J

s 	
v 
% 
 
# 
 
 	
   C6 

==> guile-2.0.14.tar.xz: lib/guile/2.0/ccache/texinfo/docbook.go <==
GOOF----LE-8-2.0;&      ]  4 h      ] g  guile	 	g  define-module*	 	 	g  texinfo	g  docbook	 		g  filenameS	
f  texinfo/docbook.scm	g  importsS	g  sxml	
g  fold	
 	 	g  srfi	g  srfi-1	 	g  selectS	
 	 	 	g  exportsS	g  *sdocbook->stexi-rules*	g  *sdocbook-block-commands*	g  sdocbook-flatten	g  filter-empty-elements	g  replace-titles	 	g  set-current-module	 	  	!g  identity	"g  @	#g  identity-deattr	$g  	detag-one	%g  	parameter	&g  var	'%& 	(g  replaceable	)(& 	*g  type	+g  code	,*+ 	-g  function	.-+ 	/g  literal	0g  samp	1/0 	2g  emphasis	3g  emph	423 	5g  simpara	6g  para	756 	8g  programlisting	9g  example	:89 	;g  	firstterm	<g  dfn	=;< 	>g  filename	?g  file	@>? 	Ag  quote	Bg  cite	CAB 	Dg  application	EDB 	Fg  symbol	GF+ 	Hg  note	Ig  	cartouche	JHI 	Kg  envar	Lg  env	MKL 	N'),.147:=@CEGJM 	Og  tag-replacements	Pg  ignore-list	Qg  with-output-to-string	Rg  write	Sg  	stringify	Tg  
*preorder*	Ug  %	Vg  orderedlist	Wg  listitem	Xg  item	Yg  	enumerate	Zg  itemizedlist	[g  itemize	\g  acronym	]g  term	^g  informalexample	_g  section	`g  
subsection	ag  
subsubsection	bg  ulink	cg  assq	dg  url	eg  uref	fg  title	gg  *text*	hg  	*default*	ig  append	jg  warn	kf  Ignoring	lf  
attributes	mg  memq	nf  Don't know how to convert	of  to stexi	pg  c	qg  all	rg  	indexterm	sg  variablelist	tg  refsect1	ug  refsect2	vg  refsect3	wg  refsect4	xg  
informaltable	y68^rsVtuvwf9HZx 	zg  inline-command?	{i 	|i 	}g  reverse	~g  foldts*-values	g  chapter t u_ v` wa  C 5h     ]4	
5 4  >  "  G     h   o   -  1  3  C    g       g  args
			  g  filenamef  texinfo/docbook.scm
	(
 			


  g  nameg  identity C!R"        h@      - 1 3  $  %$  &  "  "  "  C            g  tag
			; g  body			;  g  filenamef  texinfo/docbook.scm
	+
		,			,			,	(		,	!		,			-		 	-	%	$	,		'	.		:	,	 			;
  g  nameg  identity-deattr C#R     h      ]C   w       g  tag
		 g  body		  g  filenamef  texinfo/docbook.scm
	1
 			  g  nameg  	detag-one C$RNORPRQR    h   N   ] L 6F       g  filenamef  texinfo/docbook.scm
	H			H	$ 		
   C       h   u   ] O 6   m       g  exp
		
  g  filenamef  texinfo/docbook.scm
	G
	
	H	 		
  g  nameg  	stringify CSR"T!iUT!i6#iVWX   h   s   - 1 3 C k       g  tag
			 g  body			  g  filenamef  texinfo/docbook.scm
	R			S	 			
   C Y   h   s   - 1 3 C k       g  tag
			 g  body			  g  filenamef  texinfo/docbook.scm
	T			U	 			
   CZWX h   s   - 1 3 C k       g  tag
			 g  body			  g  filenamef  texinfo/docbook.scm
	W			X	 			
   C [   h   s   - 1 3 C k       g  tag
			 g  body			  g  filenamef  texinfo/docbook.scm
	Y			Z	 			
   C\\U h    s   - 1 3   C       k       g  tag
			 g  body			  g  filenamef  texinfo/docbook.scm
	[			\	 			
   C]$i^$i_!i`!ia!ibcdeUf h8      - 1 3 45$    CC              g  tag
			1 g  attrs			1 g  body				1 g  t			1  g  filenamef  texinfo/docbook.scm
	b		
	d			d			d			d			c			f		0	h	 				1	
	   Cg$ihcOi"jklmPnopUqS     h     - 1 3 4 5$  U"  	6$  =$  1&  #4 >  "  G  6"""4 	5$  C4
 >  "  G  
4 5   C        g  tag
		  g  body		  g  subst		   g  filenamef  texinfo/docbook.scm
	j		
	k	!		k			l		#	r	$	'	r		'	n		*	n	!	.	n		1	n	5	2	n	.	6	n		9	n	F	<	n	R	@	n		A	p		E	p	$	I	p	3	L	p	@	Q	p		^	q	&	a	q	2	c	q		p	s		|	l			u	 	u	 	u	> 	u	 	v	 	v	% 	v	0 	v	% 	v	 #		 
   C RyRm  h      ]4 5C          g  command
		
  g  filenamef  texinfo/docbook.scm
 
	 		 	 		
  g  nameg  inline-command? CzRU|}       h(      ]L4L $  	L  "  4 55D          g  accum
		% g  block		%  g  filenamef  texinfo/docbook.scm
 		 		
 		 	(	 	5	 		  		% 	 			%	   C        hX   n  ]  $  & $   &   "  "  "  $   "   O D  f      g  node
		V g  accum		V g  block			V g  cont			V g  command		4	V g  attrs		4	V  g  filenamef  texinfo/docbook.scm
 		 		 			 		
 		 	0	 	)	 		 		 	(	! 		$ 		4 		> 		A 		I 	$	J 		K 		V 	 		V	  g  nameg  fdown C~zi        hH   y  ]4>  G 45$  45D45D  q      g  node
		F g  paccum		F g  pblock			F g  pcont			F g  kaccum			F g  kblock			F g  kcont			F g  ret			F g  block			F  	g  filenamef  texinfo/docbook.scm
 		 	!	 		 		 		 		" 		' 		( 	&	4 		7 		@ 	*	B 		F 	 		F	  g  nameg  fup C     h      ] D          g  str
		
 g  accum		
 g  block			
 g  cont			
  g  filenamef  texinfo/docbook.scm
 		 		
 	 		
	  g  nameg  fhere C}      h0   "  ]!4 >  G 6             g  sdocbook
		) g  fdown		) g  accum			) g  block			) g  cont			)  g  filenamef  texinfo/docbook.scm
 
	 		 	:	 	>	 		 		) 	 		)  g  nameg  sdocbook-flatteng  
documentationf "Flatten" a fragment of sdocbook so that block elements do not nest
inside each other.

Docbook is a nested format, where e.g. a @code{refsect2} normally
appears inside a @code{refsect1}. Logical divisions in the document are
represented via the tree topology; a @code{refsect2} element
@emph{contains} all of the elements in its section.

On the contrary, texinfo is a flat format, in which sections are marked
off by standalone section headers like @code{@@chapter}, and block
elements do not nest inside each other.

This function takes a nested sdocbook fragment @var{sdocbook} and
flattens all of the sections, such that e.g.
@example
 (refsect1 (refsect2 (para "Hello")))
@end example
becomes
@example
 ((refsect1) (refsect2) (para "Hello"))
@end example

Oftentimes (always?) sectioning elements have @code{<title>} as their
first element child; users interested in processing the @code{refsect*}
elements into proper sectioning elements like @code{chapter} might be
interested in @code{replace-titles} and @code{filter-empty-elements}.
@xref{texinfo docbook replace-titles,,replace-titles}, and @ref{texinfo
docbook filter-empty-elements,,filter-empty-elements}.

Returns a nodeset, as described in @ref{sxml xpath}. That is to say,
this function returns an untagged list of stexi elements. CR}
    h(      ]"   C $   (  C""          g  x
		% g  rest		%  g  filenamef  texinfo/docbook.scm
 		 	
	 		 		 		 	 	 	
 		%	   C      h      ]4 56      g  sdocbook
		  g  filenamef  texinfo/docbook.scm
 
	 		
 		 		 	 		  g  nameg  filter-empty-elementsg  
documentationf  gFilters out empty elements in an sdocbook nodeset. Mostly useful
after running @code{sdocbook-flatten}. CR}c   hh     ]"  U(  6$  45"  $  "" "        g  sdocbook-fragment
		f g  in		[ g  out			[ g  t		*	[  g  filenamef  texinfo/docbook.scm
 
	 		 		 		 		 		 		 		  	"	# 		% 		* 		5 		9 	"	< 	/	? 		B 		J 		M 	
	P 		S 		[ 		[ 		^ 	'	f 	 		f  g  nameg  replace-titlesg  
documentationf rIterate over the sdocbook nodeset @var{sdocbook-fragment},
transforming contiguous @code{refsect} and @code{title} elements into
the appropriate texinfo sectioning command. Most useful after having run
@code{sdocbook-flatten}.

For example:
@example
 (replace-titles '((refsect1) (title "Foo") (para "Bar.")))
    @result{} '((chapter "Foo") (para "Bar."))
@end example
 CRC          g  m
		,  g  filenamef  texinfo/docbook.scm		
 	(
	+
	1
	5		4
	E		E
	G
	N	
q	J

s 	
v 
% 
 
# 
 
 	
   C6 
